# -*- encoding: utf-8 -*-
from django.core.exceptions import ValidationError
from django.template import Template
from django.utils.translation import ugettext_lazy as _


def TemplateValidator(value):
    """Try to compile a string into a Django template"""

    try:
        Template(value)
    except Exception as e:
        raise ValidationError(
            _("Cannot compile template (%(exception)s)"),
            params={"exception": e}
        )



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-30 23:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('flexible_reports', '0006_default_ordering'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='columnorder',
            options={'verbose_name': 'Column order information', 'verbose_name_plural': 'Column order informations'},
        ),
        migrations.AddField(
            model_name='columnorder',
            name='desc',
            field=models.BooleanField(default=False, verbose_name='Descending'),
        ),
    ]



# -*- encoding: utf-8 -*-
from django import forms
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from flexible_reports.admin.helpers import BiggerTextarea
from .helpers import SmallerTextarea
from .helpers import SortableHiddenMixin
from ..models import Report
from ..models.report import ReportElement


class ReportElementForm(forms.ModelForm):
    class Meta:
        widgets = {
            'title': SmallerTextarea,
        }


class ReportElementInline(SortableHiddenMixin,
                          admin.StackedInline):
    extra = 0

    model = ReportElement

    form = ReportElementForm

    fields = ['title',
              'slug',
              'data_from',
              'datasource',
              'base_model',
              'table',
              'position']

    prepopulated_fields = {'slug': ['title',]}


class ReportForm(forms.ModelForm):
    class Meta:
        widgets = {
            'title': SmallerTextarea,
            'template': BiggerTextarea
        }


@admin.register(Report)
class ReportAdmin(admin.ModelAdmin):
    list_display = ['title', 'slug', 'elements']
    inlines = [ReportElementInline, ]
    form = ReportForm
    prepopulated_fields = {"slug": ("title",)}

    def elements(self, obj):
        return ", ".join([x.title for x in obj.reportelement_set.all()])
    elements.short_description = _("Report's elements")



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-25 10:58
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('flexible_reports', '0008_auto_20171025_0553'),
    ]

    operations = [
        migrations.AlterField(
            model_name='reportelement',
            name='datasource',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='flexible_reports.Datasource', verbose_name='Datasource'),
        ),
    ]
